@@ -1,14 +1,15 @@
 package Encode::TW;
+
 BEGIN {
-    if (ord("A") == 193) {
-	die "Encode::TW not supported on EBCDIC\n";
+    if ( ord("A") == 193 ) {
+        die "Encode::TW not supported on EBCDIC\n";
     }
 }
-our $VERSION = do { my @r = (q$Revision: 1.25 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = ( q$Revision: 2.1 $ =~ /\d+/g ); sprintf "%d." . "%02d" x $#r, @r };
 
 use Encode;
 use XSLoader;
-XSLoader::load(__PACKAGE__,$VERSION);
+XSLoader::load( __PACKAGE__, $VERSION );
 
 1;
 __END__
@@ -32,8 +33,10 @@ Encodings supported are as follows.
   Canonical   Alias		Description
   --------------------------------------------------------------------
   big5-eten   /\bbig-?5$/i	Big5 encoding (with ETen extensions)
-	      /\bbig5-?et(en)?$/i
+          /\bbig5-?et(en)?$/i
+          /\btca-?big5$/i
   big5-hkscs  /\bbig5-?hk(scs)?$/i
+              /\bhk(scs)?-?big5$/i
                                 Big5 + Cantonese characters in Hong Kong
   MacChineseTrad		Big5 + Apple Vendor Mappings
   cp950		                Code Page 950 
